//
//  MyController.m
//  RPG-Generator
//
//  Created by Holger Hinzberg on 27.09.09.
//  Copyright 2009 Cocoa-Coding. All rights reserved.
//

#import "MyController.h"

@implementation MyController

- init
{
	if (self = [super init])
	{
		rpgDice = [[Dice alloc] init];
		rpgCharacter = [[Character alloc] init];		
		racesArray = [[NSMutableArray alloc] init];	
		classesArray = [[NSMutableArray alloc] init];	
	}
	return self;	
}

- (Character *)rpgCharacter {
    return [[rpgCharacter retain] autorelease];
}

- (void)setRpgCharacter:(Character *)value {
    if (rpgCharacter != value) {
        [rpgCharacter release];
        rpgCharacter = [value copy];
    }
}

- (IBAction)rollCharacterAttributes:(id)sender
{
	[rpgCharacter setStrength: [rpgDice Roll3W6]];
	[rpgCharacter setDexterity: [rpgDice Roll3W6]];
	[rpgCharacter setConstitution: [rpgDice Roll3W6]];
	[rpgCharacter setIntelligence: [rpgDice Roll3W6]];
	[rpgCharacter setWisdom: [rpgDice Roll3W6]];
	[rpgCharacter setCharisma: [rpgDice Roll3W6]];
	
	[self determinePossibleRaces];
	[self determinePossibleClasses];
 }

- (void)determinePossibleRaces
{
	[racesArray removeAllObjects];
	
	Race *aRace = [[Race alloc] initWithName:@"Mensch"];
	[racesArray addObject:aRace];
	[rpgCharacter setRace:[aRace racename]];
	
	int strength     = [[rpgCharacter strength] intValue];
	int dexterity    = [[rpgCharacter dexterity] intValue];
	int constitution = [[rpgCharacter constitution] intValue];
	int intelligence = [[rpgCharacter intelligence] intValue];
	int wisdom		 = [[rpgCharacter wisdom] intValue];
	int charisma	 = [[rpgCharacter charisma] intValue];
	
	if(strength >= 3 && dexterity >= 6 && constitution >= 7
	   && intelligence >= 8 && wisdom >= 3 && charisma >= 8)
	{
		[racesArray addObject:
			[[Race alloc] initWithName:@"Elfe"]	];
	}
	
	if(strength >= 6 && dexterity >= 3 && constitution >= 8
	   && intelligence >= 6 && wisdom >= 3 && charisma >= 3)
	{
		[racesArray addObject:
			[[Race alloc] initWithName:@"Gnom"]	];
	}
	
	if(strength >= 3 && dexterity >= 6 && constitution >= 6
	   && intelligence >= 4 && wisdom >= 3 && charisma >= 3)
	{
		[racesArray addObject:
			[[Race alloc] initWithName:@"Halbelfe"]	];
	}
	
	if(strength >= 7 && dexterity >= 7 && constitution >= 10
	   && intelligence >= 6 && wisdom >= 3 && charisma >= 3)
	{
		[racesArray addObject:
			[[Race alloc] initWithName:@"Halbling"]	];
	}
		
	if(strength >= 8 && dexterity >= 7 && constitution >= 11
	   && intelligence >= 3 && wisdom >= 3 && charisma >= 3)
	{
		[racesArray addObject:
			[[Race alloc] initWithName:@"Zwerg"] ];
	}
	
	[myRacesController rearrangeObjects];
}

- (void)determinePossibleClasses
{
	[classesArray removeAllObjects];
	
	int strength     = [[rpgCharacter strength] intValue];
	int dexterity    = [[rpgCharacter dexterity] intValue];
	int constitution = [[rpgCharacter constitution] intValue];
	int intelligence = [[rpgCharacter intelligence] intValue];
	int wisdom		 = [[rpgCharacter wisdom] intValue];
	int charisma	 = [[rpgCharacter charisma] intValue];

	if(strength >= 9)
	{
		[classesArray addObject:
		 [[CharClass alloc] initWithClassname:@"Kämpfer"]];
	}
	
	if(strength >= 12 && constitution >= 9 )
	{
		[classesArray addObject:
		[[CharClass alloc] initWithClassname:@"Paladin"]];
	}
	
	if(strength >= 13 && dexterity >= 13 && constitution >= 14
	   && wisdom >= 14)
	{
		[classesArray addObject:
		[[CharClass alloc] initWithClassname:@"Waldläufer"]];
	}
	
	if( intelligence >= 9)
	{
		[classesArray addObject:
		[[CharClass alloc] initWithClassname:@"Zauberkundiger"]];
	}
		
	if(wisdom >= 9)
	{
		[classesArray addObject:
		 [[CharClass alloc] initWithClassname:@"Kleriker"]];
	}
	
	if(wisdom >= 12 && charisma >= 15)
	{
		[classesArray addObject:
		[[CharClass alloc] initWithClassname:@"Druide"]];
	}
	
	if(dexterity >= 9)
	{
		[classesArray addObject:
		[[CharClass alloc] initWithClassname:@"Dieb"]];
	}
	
	if(dexterity >= 12 && intelligence >= 13 && charisma >= 15)
	{
		[classesArray addObject:
		 [[CharClass alloc] initWithClassname:@"Barde"]];
	}
		
	[rpgCharacter setCharClass:
	[[classesArray objectAtIndex:0] classname]];
	[myClassesController rearrangeObjects];
}

- (IBAction)saveCharacter:(id)sender
{
	NSSavePanel *aSavePanel = [NSSavePanel savePanel];
	[aSavePanel setRequiredFileType:@"crpg"];
	[aSavePanel setTitle:@"Character speichern"];
	[aSavePanel setPrompt:@"Speichern"];
	
	if ([aSavePanel runModal] == NSOKButton)
	{
		NSString *filename = [aSavePanel filename];
		BOOL result = [NSKeyedArchiver archiveRootObject:rpgCharacter toFile:filename];
		
		if (result == FALSE)
		{
			NSLog(@"Ein Fehler ist aufgetreten");
		}
	}	
}

- (IBAction)loadCharacter:(id)sender
{
	NSOpenPanel *aOpenPanel = [NSOpenPanel openPanel];
	[aOpenPanel setRequiredFileType:@"crpg"];
	[aOpenPanel setTitle:@"Character laden"];
	[aOpenPanel setPrompt:@"Laden"];
	
	if ([aOpenPanel runModal] == NSOKButton)
	{
		NSString *filename = [aOpenPanel filename];
		
		Character *aCharacter = [NSKeyedUnarchiver unarchiveObjectWithFile:filename];
		
		[rpgCharacter setCharacterName:[aCharacter characterName]];
		[rpgCharacter setImage:[aCharacter image]];
		
		[rpgCharacter setStrength:[aCharacter strength]];
		[rpgCharacter setDexterity:[aCharacter dexterity]];
		[rpgCharacter setConstitution:[aCharacter constitution]];
		[rpgCharacter setIntelligence:[aCharacter intelligence]];
		[rpgCharacter setWisdom:[aCharacter wisdom]];
		[rpgCharacter setCharisma:[aCharacter charisma]];
		
		[self determinePossibleRaces];
		[self determinePossibleClasses];
		
		[rpgCharacter setRace:[aCharacter race]];
		[rpgCharacter setCharClass:[aCharacter charClass]];
		
		
		[self determinePossibleRaces];
		[self determinePossibleClasses];
		
		//[self setRpgCharacter:[NSKeyedUnarchiver unarchiveObjectWithFile:filename]];
		
		
	}
}


- (IBAction)testBinding:(id)sender
{
	if ([myCharacterController commitEditing] == YES )
	{
		NSLog(@"Name: %@", [rpgCharacter characterName] );
		NSLog(@"Rasse: %@", [rpgCharacter race] );	
		NSLog(@"Rasse: %@", [rpgCharacter charClass] );	
		NSLog(@"Stärke: %@", [rpgCharacter strength]  );	
	}	
}


@end
